@@ -7,15 +7,15 @@ class ThreadPool():
     """ 维护一个线程池 """
     
     def __init__(self, size):
+        self.size = size
         self.locks = []
-        self.maxsize = size
         
     def clear(self):
         self.locks.clear()
 
     def run(self, func, args, kwargs={}):
         """ 主线程命令当前线程池从空闲线程中取一个线程执行给入的方法，如果池满，则主线程等待 """
-        if len(self.locks) < self.maxsize:
+        if len(self.locks) < self.size:
             lock = _thread.allocate_lock()
             lock.acquire()
             self.locks.append(lock)
@@ -23,7 +23,7 @@ class ThreadPool():
             newfunc = self._getnewfunc(func)
             _thread.start_new_thread(newfunc, args, kwargs)
         else:
-            while len(self.locks) >= self.maxsize:
+            while len(self.locks) >= self.size:
                 for lock in self.locks:
                     if not lock.locked():
                         self.locks.remove(lock)
