@@ -1,13 +1,13 @@
 from tools_hjh.DBConn import DBConn
-from tools_hjh.DBConn import oracletools
-from tools_hjh.DBConn import MemoryDB
+from tools_hjh.OracleTools import OracleTools
+from tools_hjh.MemoryDB import MemoryDB
 
 from tools_hjh.SSHConn import SSHConn
 
 from tools_hjh.ThreadPool import ThreadPool
 
-from tools_hjh.HttpRequest import HttpRequest
-from tools_hjh.HttpRequest import httptools
+from tools_hjh.HTTPRequest import HTTPRequest
+from tools_hjh.HTTPTools import HTTPTools
 
 from tools_hjh.other import Log
 
@@ -18,9 +18,9 @@ from tools_hjh.other import sql_remove_comments
 from tools_hjh.other import echo
 from tools_hjh.other import mkdir
 from tools_hjh.other import rm
-from tools_hjh.other import spacesmerge
+from tools_hjh.other import merge_spaces
 from tools_hjh.other import nvl
 from tools_hjh.other import round_
 from tools_hjh.other import timeformat
-from tools_hjh.other import zipfolder
-from tools_hjh.other import picturesFolder2PDF
+from tools_hjh.other import zip_folder
+from tools_hjh.other import pictures_folder_2_pdf
